has_own_property

Function has_own_property 

pub fn has_own_property(
    cx: JSContext,
    object: HandleObject<'_>,
    property: &CStr,
) -> Result<bool, ()>
Checks whether object has an own property named property. Returns Err(()) on JSAPI failure (there is a pending exception), and Ok(false) for null objects or when the property is not own.