pub fn has_property_on_prototype(
cx: &mut JSContext,
proxy: HandleObject<'_>,
id: HandleId<'_>,
found: &mut bool,
) -> boolExpand description
Computes whether proxy has a property id on its prototype and stores
the result in found.
Returns a boolean indicating whether the check succeeded.
If false is returned then the value of found is unspecified.