pub(crate) unsafe extern "C" fn resolve_global(
cx: *mut RawJSContext,
obj: HandleObject,
id: HandleId,
rval: *mut bool,
) -> boolExpand description
Resolve a lazy global property, for interface objects and named constructors.
pub(crate) unsafe extern "C" fn resolve_global(
cx: *mut RawJSContext,
obj: HandleObject,
id: HandleId,
rval: *mut bool,
) -> boolResolve a lazy global property, for interface objects and named constructors.