pub struct CallPolicyInfo {
pub lenient_this: bool,
pub needs_security_check_on_interface_match: bool,
}Expand description
Controls various details of an IDL operation, such as whether a
[LegacyLenientThis] attribute is specified and preconditions that
affect the outcome of the “perform a security check” steps.
Fields
lenient_this: boolSpecifies whether a [LegacyLenientThis] attribute is specified on the
interface member this operation is associated with.
needs_security_check_on_interface_match: boolIndicates whether a security check is required if the target object implements this operation’s interface.
Regardless of this value, performing a security check is always necessary if the target object doesn’t implement this operation’s interface.
This field is false iff any of the following are true:
-
The operation is not implemented by any cross-origin objects (i.e., any
WindoworLocationobjects). -
The operation is defined as cross origin (i.e., it’s included in
CrossOriginProperties(obj), givenobjimplementing the operation’s interface).